==> redquicklib-1.328.0.tgz: package/lib/actions/identityLoginActions.js <==
import service from '../service';
import * as UIA from './uiActions';
import accountverificationservice from '../accountverificationservice';
import { Actions } from 'react-native-router-flux';
import locationservice from '../locationservice';
import userservice from '../userservice';
var ReactNative = require('react-native');

var {
    AsyncStorage
} = ReactNative;
var _s = service();

export const setBearerToken = (bearerToken) => {
    return (dispatch, getState) => {
        _s.setBearerAccessToken(bearerToken);
        dispatch(_setBearerToken(bearerToken));
    };
}
export const logout = (callback) => {
    return (dispatch, getState) => {
        locationservice.stop();

        return AsyncStorage.setItem('bearer-token', '').then(() => {
            return AsyncStorage.setItem(UIA.SIGNED_OUT, 'true');
        }).then(() => {
            if (callback)
                callback();
        });
    };
}
export const startLocationService = () => {
    return (dispatch, getState) => {
        return locationservice.start(dispatch, getState);
    }
}
export const LOGGING_IN_PROCESS = 'LOGGING_IN_PROCESS';
export const loginProcess = (bearerToken, onloginfail, onsuccess) => {
    return (dispatch, getState) => {
        if (bearerToken && !UIA.IsBusy(getState(), [LOGGING_IN_PROCESS])) {
            dispatch(UIA.UI(LOGGING_IN_PROCESS, true));
            _s.setBearerAccessToken(bearerToken);
            dispatch(_setBearerToken(bearerToken));
            var uniqueMachineSig = UIA.Get(getState(), UIA.UNIQUE_MACHINE_SIG);
            ws.setUniqueId(uniqueMachineSig);
            return accountverificationservice.login(uniqueMachineSig).then(res => {
                dispatch(UIA.UI(IS_CUSTOMER, res));
                if (res) {
                    // dispatch(UIA.UI(UIA.SIGNED_OUT, false, true));
                    AsyncStorage.setItem(UIA.SIGNED_OUT, 'false');
                    AsyncStorage.setItem('bearer-token', bearerToken);
                    dispatch(UIA.UI(UIA.CHECKING_IF_IS_PENDING_IDENTITY_CONFIRMATION, true));
                    return accountverificationservice.isPendingIdentityConfirmation().then(res => {
                        dispatch(UIA.UI(IS_PENDING_IDENTITY_CONFIRMATION, res));
                        dispatch(UIA.UI(UIA.CHECKING_IF_IS_PENDING_IDENTITY_CONFIRMATION, false));
                        if (res) {
                            Actions.AccountVerificationCodeEntry();
                        }
                        else {

                            dispatch(UIA.UI(UIA.CHECKING_IF_VERIFIED, true));
                            return accountverificationservice.isVerified().then(res => {
                                dispatch(UIA.UI(IS_VERIFIED, res));
                                if (res) {
                                    locationservice.start(dispatch, getState);
                                    // This could go to  the payment option page right away.
                                    // return CA._loadCustomer(dispatch, getState).then(() => {
                                    //     return AVA._loadModeChoices(dispatch, getState).then(() => {
                                    //         if (AVA.IsOnlyCustomer(getState())) {
                                    //             // Actions.Home({ type: 'reset' });
                                    //             VA.navigateCust({ initial: true })(dispatch, getState);
                                    //         }
                                    //         else {
                                    //             Actions.ModeChoice();
                                    //         }
                                    //     })
                                    // });
                                }
                                else {
                                    // Actions.AccountVerification();
                                }
                            }).then(() => {
                                dispatch(UIA.UI(UIA.CHECKING_IF_VERIFIED, false));
                            });
                        }
                    }).then(() => {
                        return userservice.getPermissions().catch(UIA._catch).then(permissions => {
                            dispatch(UIA.UI(UIA.PERMISSIONS, permissions));
                        })
                    }).then(() => {
                        startLocationService()(dispatch, getState);
                    });
                }
                else {
                    if (onloginfail) {
                        onloginfail();
                    }
                }
            }).catch(UIA._catch).then(() => {
                dispatch(UIA.UI(LOGGING_IN_PROCESS, false));
                if (onsuccess) {
                    onsuccess();
                }
            });
        }
    }
}

export const IS_PENDING_IDENTITY_CONFIRMATION = 'IS_PENDING_IDENTITY_CONFIRMATION';
export const IS_CUSTOMER = 'IS_CUSTOMER';
export const IS_VERIFIED = 'IS_VERIFIED';
function _setIsCustomer(isCustomer) {
    return {
        type: IS_CUSTOMER,
        isCustomer
    }
}

export const AUTH_REDUCER = "authReducer";
export const SET_BEARER_TOKEN = 'SET_BEARER_TOKEN';
function _setBearerToken(bearerToken) {
    return {
        type: SET_BEARER_TOKEN,
        bearerToken,
        store: AUTH_REDUCER
    }
}

==> redquicklib-1.376.0.tgz: package/lib/actions/identityLoginActions.js <==
import service from '../service';
import * as UIA from './uiActions';
import accountverificationservice from '../accountverificationservice';
import { Actions } from 'react-native-router-flux';
import locationservice from '../locationservice';
import userservice from '../userservice';
var ReactNative = require('react-native');

var {
    AsyncStorage
} = ReactNative;
var _s = service();

export const setBearerToken = (bearerToken) => {
    return (dispatch, getState) => {
        _s.setBearerAccessToken(bearerToken);
        dispatch(_setBearerToken(bearerToken));
    };
}
export const logout = (callback) => {
    return (dispatch, getState) => {
        locationservice.stop();

        return AsyncStorage.setItem('bearer-token', '').then(() => {
            return AsyncStorage.setItem(UIA.SIGNED_OUT, 'true');
        }).then(() => {
            if (callback)
                callback();
        });
    };
}
export const startLocationService = () => {
    return (dispatch, getState) => {
        return locationservice.start(dispatch, getState);
    }
}
export const LOGGING_IN_PROCESS = 'LOGGING_IN_PROCESS';
export const loginProcess = (bearerToken, onloginfail, onsuccess) => {
    return (dispatch, getState) => {
        if (bearerToken && !UIA.IsBusy(getState(), [LOGGING_IN_PROCESS])) {
            dispatch(UIA.UI(LOGGING_IN_PROCESS, true));
            dispatch(UIA.UI(UIA.BEARER_TOKEN, bearerToken));
            _s.setBearerAccessToken(bearerToken);
            dispatch(_setBearerToken(bearerToken));
            var uniqueMachineSig = UIA.Get(getState(), UIA.UNIQUE_MACHINE_SIG);
            AsyncStorage.setItem(UIA.SIGNED_OUT, 'false');
            AsyncStorage.setItem('bearer-token', bearerToken);
            locationservice.start(dispatch, getState);
            if (onsuccess) {
                onsuccess();
            }
        }
    }
}

export const IS_PENDING_IDENTITY_CONFIRMATION = 'IS_PENDING_IDENTITY_CONFIRMATION';
export const IS_CUSTOMER = 'IS_CUSTOMER';
export const IS_VERIFIED = 'IS_VERIFIED';
function _setIsCustomer(isCustomer) {
    return {
        type: IS_CUSTOMER,
        isCustomer
    }
}

export const AUTH_REDUCER = "authReducer";
export const SET_BEARER_TOKEN = 'SET_BEARER_TOKEN';
function _setBearerToken(bearerToken) {
    return {
        type: SET_BEARER_TOKEN,
        bearerToken,
        store: AUTH_REDUCER
    }
}
